@@ -120,14 +120,15 @@ def _format(response):
 
 class Payment(MuviBase):
     def __init__(self, processor: str, url: str, private_key: str, public_key: str, merchant_name: str, site_id: str,
-                 site_id_cadena: str, marketplace: bool):
+                 site_id_cadena_con_cvv: str, site_id_cadena_sin_cvv: str, marketplace: bool):
         super().__init__(processor)
         self.url = url
         self.private_key = private_key
         self.public_key = public_key
         self.merchant_name = merchant_name
         self.site_id = site_id
-        self.site_id_cadena = site_id_cadena
+        self.site_id_cadena_con_cvv = site_id_cadena_con_cvv
+        self.site_id_cadena_sin_cvv = site_id_cadena_sin_cvv
         self.marketplace = marketplace
         self.headers = {
             'apikey': self.private_key,
@@ -135,16 +136,25 @@ class Payment(MuviBase):
             'Cache-Control': 'no-cache'
         }
 
-    def create(self, payment_data: dict):
-        site_transaction_id = int(time.time()*1e2)
+    def create(self, payment_data: dict, con_cvv: bool = False):
+        site_transaction_id = int(time.time()*1e2) # Se genera un payment_id para decidir
         total_amount = round(payment_data['transaction_amount'], 2) * 100  # se multiplica por 100; no acepta decimales
         installments = payment_data['installments'] if 'installments' in payment_data else 1
+        
+        if con_cvv:
+            site_id = self.site_id_cadena_con_cvv
+        else:
+            if self.marketplace:
+                site_id = self.site_id_cadena_sin_cvv
+            else:
+                site_id = self.site_id
+
         body = {
             'customer': {
                 'id': payment_data['payer']['decidir_id'],
                 'email': payment_data['payer']['email']
             },
-            'site_id': self.site_id_cadena if self.marketplace else self.site_id,
+            'site_id': site_id,
             'site_transaction_id': str(site_transaction_id),
             'token': payment_data['token'],
             'payment_method_id': payment_data['payment_method_id'] if 'payment_method_id' in payment_data else 1,
@@ -161,7 +171,7 @@ class Payment(MuviBase):
             body['payment_type'] = 'distributed'
             body['sub_payments'] = [
                 {
-                    'site_id': self.site_id_cadena,
+                    'site_id': self.site_id_cadena_sin_cvv,
                     'installments': installments,
                     'amount': application_fee
                 }, {
